// /**
// * Copyright (c) 2012-2025 SAP SE or an SAP affiliate company. All rights reserved.
// * Theming Engine 15.0.1
// * data:{"sModified":"2025-03-20T15:24:53Z"}
// */


/******************* FILE /Base/baseLib/sap_fiori_3_dark/base.less (Version 11.28.2) *******************/


// [Tags "SapInternal", "Base", "Dimension", "Protected"]
// [Protected "true"]
// [Category "Internal"]
// [Type "dimension"]
@sapContent_GridSize: 1rem;

// [Tags "SapInternal", "Base", "Palette", "Color", "Protected"]
// [Protected "true"]
// [Category "Internal"]
// [Type "color"]
@sapPrimary1: #354a5f;

// [Tags "SapInternal", "Base", "Palette", "Color", "Protected"]
// [Protected "true"]
// [Category "Internal"]
// [Type "color"]
@sapPrimary2: #91c8f6;

// [Tags "SapInternal", "Base", "Palette", "Color", "Protected"]
// [Protected "true"]
// [Category "Internal"]
// [Type "color"]
@sapPrimary3: #29313a;

// [Tags "SapInternal", "Base", "Palette", "Color", "Protected"]
// [Protected "true"]
// [Category "Internal"]
// [Type "color"]
@sapPrimary4: #232a31;

// [Tags "SapInternal", "Base", "Palette", "Color", "Protected"]
// [Protected "true"]
// [Category "Internal"]
// [Type "color"]
@sapPrimary5: #8696a9;

// [Tags "SapInternal", "Base", "Palette", "Color", "Protected"]
// [Protected "true"]
// [Category "Internal"]
// [Type "color"]
@sapPrimary6: #fafafa;

// [Tags "SapInternal", "Base", "Palette", "Color", "Protected"]
// [Protected "true"]
// [Category "Internal"]
// [Type "color"]
@sapPrimary7: #d3d7d9;

// [Label "Shell Background Pattern Color"]
// [Description "The background pattern color of the shell. To turn off the pattern set the value to 'transparent'."]
// [Tags "ThemeSpecific", "Base", "Shell", "Color", "!Protected"]
// [Protected "!true"]
// [Category "Resource"]
// [Type "color"]
@sapShell_BackgroundPatternColor: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapBrandColor: @sapPrimary2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapHighlightColor: @sapBrandColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapBaseColor: @sapPrimary3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShellColor: @sapPrimary1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapBackgroundColor: darken(@sapPrimary3, 6);

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontFamily: "72", "72full", Arial, Helvetica, sans-serif;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontSize: 0.875 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTextColor: @sapPrimary6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLinkColor: darken(@sapPrimary2, 22);

// [Tags "!Protected"]
// [Protected "!true"]
@sapCompanyLogo: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFavicon: @sapShell_Favicon;

// [Tags "!Protected"]
// [Protected "!true"]
@sapBackgroundImage: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapBackgroundImageOpacity: 1.0;

// [Tags "!Protected"]
// [Protected "!true"]
@sapBackgroundImageRepeat: false;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSelectedColor: @sapHighlightColor;
@sapHoverColor: lighten(@sapBackgroundColor, 3);

// [Tags "!Protected"]
// [Protected "!true"]
@sapActiveColor: @sapHighlightColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapHighlightTextColor: contrast(@sapHighlightColor, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTitleColor: @sapTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapNegativeColor: #ff8888;

// [Tags "!Protected"]
// [Protected "!true"]
@sapCriticalColor: #fabd64;

// [Tags "!Protected"]
// [Protected "!true"]
@sapPositiveColor: #abe2ab;

// [Tags "!Protected"]
// [Protected "!true"]
@sapInformativeColor: #91c8f6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapNeutralColor: #d3d7d9;

// [Tags "!Protected"]
// [Protected "!true"]
@sapNegativeElementColor: @sapNegativeColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapCriticalElementColor: @sapCriticalColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapPositiveElementColor: @sapPositiveColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapInformativeElementColor: @sapInformativeColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapNeutralElementColor: @sapNeutralColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapNegativeTextColor: @sapNegativeColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapCriticalTextColor: @sapCriticalColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapPositiveTextColor: @sapPositiveColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapInformativeTextColor: @sapInformativeColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapNeutralTextColor: @sapNeutralColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapErrorColor: @sapNegativeColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapWarningColor: @sapCriticalColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSuccessColor: @sapPositiveColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapInformationColor: @sapInformativeColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapErrorBackground: darken(@sapErrorColor, 65);

// [Tags "!Protected"]
// [Protected "!true"]
@sapWarningBackground: darken(@sapWarningColor, 60);

// [Tags "!Protected"]
// [Protected "!true"]
@sapSuccessBackground: darken(@sapSuccessColor, 62);

// [Tags "!Protected"]
// [Protected "!true"]
@sapInformationBackground: darken(@sapInformationColor, 60);

// [Tags "!Protected"]
// [Protected "!true"]
@sapNeutralBackground: darken(@sapNeutralColor, 45);

// [Tags "!Protected"]
// [Protected "!true"]
@sapErrorBorderColor: @sapErrorColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapWarningBorderColor: @sapWarningColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSuccessBorderColor: @sapSuccessColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapInformationBorderColor: @sapInformationColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapNeutralBorderColor: @sapNeutralColor;

// [Tags "Protected"]
// [Protected "true"]
@sapElement_LineHeight: 2.75 * @sapContent_GridSize;

// [Tags "Protected"]
// [Protected "true"]
@sapElement_Height: 2.25 * @sapContent_GridSize;

// [Tags "Protected"]
// [Protected "true"]
@sapElement_BorderWidth: 0.0625 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapElement_BorderCornerRadius: 0.25 * @sapContent_GridSize;

// [Tags "Protected"]
// [Protected "true"]
@sapElement_Compact_LineHeight: 2 * @sapContent_GridSize;

// [Tags "Protected"]
// [Protected "true"]
@sapElement_Compact_Height: 1.625 * @sapContent_GridSize;

// [Tags "Protected"]
// [Protected "true"]
@sapElement_Condensed_LineHeight: 1.5 * @sapContent_GridSize;

// [Tags "Protected"]
// [Protected "true"]
@sapElement_Condensed_Height: 1.375 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_LineHeight: 1.4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_IconHeight: @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_IconColor: @sapHighlightColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ContrastIconColor: @sapContent_ContrastTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_NonInteractiveIconColor: @sapPrimary7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_MarkerIconColor: @sapAccentColor6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_MarkerTextColor: @sapAccentColor7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_MeasureIndicatorColor: @sapField_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Selected_MeasureIndicatorColor: @sapField_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Placeholderloading_Background: lighten(@sapBaseColor, 20);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Placeholderloading_Gradient: linear-gradient(to right, @sapContent_Placeholderloading_Background 0%, @sapContent_Placeholderloading_Background 20%, lighten(@sapContent_Placeholderloading_Background, 20) 50%, @sapContent_Placeholderloading_Background 80%, @sapContent_Placeholderloading_Background 100%);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ImagePlaceholderBackground: lighten(@sapBaseColor, 30);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ImagePlaceholderForegroundColor: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_RatedColor: @sapAccentColor1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_UnratedColor: @sapPrimary5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_BusyColor: @sapContent_IconColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_FocusColor: #fff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_FocusStyle: dotted;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_FocusWidth: 0.0625 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ContrastFocusColor: #000;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ShadowColor: #000;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ContrastShadowColor: #fff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Shadow0: 0 0 0 0.0625rem fade(@sapContent_ContrastShadowColor, 20), 0 0.125rem 0.5rem 0 fade(@sapContent_ShadowColor, 30);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Shadow1: 0 0 0 0.0625rem fade(@sapContent_ContrastShadowColor, 50), 0 0.125rem 0.5rem 0 fade(@sapContent_ShadowColor, 60);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Shadow2: 0 0 0 0.0625rem fade(@sapContent_ContrastShadowColor, 50), 0 0.625rem 1.875rem 0 fade(@sapContent_ShadowColor, 60);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Shadow3: 0 0 0 0.0625rem fade(@sapContent_ContrastShadowColor, 50), 0 1.25rem 5rem 0 fade(@sapContent_ShadowColor, 60);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_TextShadow: 0 0 0.125rem @sapContent_ShadowColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ContrastTextShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_HeaderShadow: 0 0.125rem 0.125rem 0 fade(@sapContent_ShadowColor, 20), inset 0 -0.0625rem 0 0 @sapObjectHeader_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Interaction_Shadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Selected_Shadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Negative_Shadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Critical_Shadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Positive_Shadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Informative_Shadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Neutral_Shadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_SearchHighlightColor: #058088;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_HelpColor: #57b900;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_LabelColor: @sapPrimary7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_MonospaceFontFamily: "72Mono", "72Monofull", lucida console, monospace;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_MonospaceBoldFontFamily: "72Mono-Bold", "72Mono-Boldfull", lucida console, monospace;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_IconFontFamily: "SAP-icons";

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_DisabledTextColor: fade(@sapTextColor, (100 - (@sapContent_DisabledOpacity * 100)));

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_DisabledOpacity: 0.4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ContrastTextThreshold: 0.55;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ContrastTextColor: @sapPrimary3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ForegroundColor: darken(@sapBaseColor, 6.1);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ForegroundBorderColor: @sapPrimary5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ForegroundTextColor: contrast(@sapContent_ForegroundColor, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_BadgeBackground: darken(saturate(@sapAccentColor2, 1), 23);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_BadgeTextColor: contrast(@sapContent_BadgeBackground, lighten(@sapTextColor, 2), @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_BadgeBorderColor: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_DragAndDropActiveColor: @sapActiveColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Selected_TextColor: contrast(@sapContent_Selected_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Selected_Background: @sapSelectedColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Selected_Hover_Background: darken(@sapContent_Selected_Background, 3);

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Selected_ForegroundColor: @sapSelectedColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_ForcedColorAdjust: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Lite_Shadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color1: #9b015d;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color2: #4d82b8;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color3: #ff7f4c;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color4: #030303;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color5: #727f87;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color6: #9ba4aa;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color7: #101619;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color8: #d5dadd;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color9: #0899a7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color10: #ebf8ff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color11: #fa4f96;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color12: #00a800;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color13: #3b5b7c;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color14: #2a4259;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color15: #c35500;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color16: #8d2a00;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color17: #046c7c;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color18: #2a4259;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color19: #324e6b;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color20: #222f3b;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color21: #101619;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color22: #00144a;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color23: #d20a0a;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color24: #d094b0;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color25: #d0c1cb;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color26: #d0b863;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color27: #d0cdb3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color28: #a93e00;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color29: #450b00;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color30: #340800;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Illustrative_Color31: #ffab92;
@sapContent_Space_S: 1rem;
@sapContent_Space_M: 2rem;
@sapContent_Space_L: 2rem;
@sapContent_Space_XL: 3rem;
@sapContent_Space_Tiny: 2rem;
@sapContent_Space_Small: 1rem;
@sapContent_Space_Medium: 2rem;
@sapContent_Space_Large: 3rem;
@sapContent_Margin_Tiny: 0 0 1rem;
@sapContent_Margin_Small: 1rem;
@sapContent_Margin_Medium: 1rem 2rem;
@sapContent_Margin_Large: 1rem 3rem;
@sapContent_Padding_S: 0rem;
@sapContent_Padding_M: 2rem;
@sapContent_Padding_L: 2rem;
@sapContent_Padding_XL: 3rem;
@sapContent_Gap: 1rem;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Success_HeaderShadow: 0 0.125rem 0.125rem 0 fade(@sapContent_ShadowColor, 20), inset 0 -0.0625rem 0 0 @sapSuccessBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Warning_HeaderShadow: 0 0.125rem 0.125rem 0 fade(@sapContent_ShadowColor, 20), inset 0 -0.0625rem 0 0 @sapWarningBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Error_HeaderShadow: 0 0.125rem 0.125rem 0 fade(@sapContent_ShadowColor, 20), inset 0 -0.0625rem 0 0 @sapErrorBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapContent_Information_HeaderShadow: 0 0.125rem 0.125rem 0 fade(@sapContent_ShadowColor, 20), inset 0 -0.0625rem 0 0 @sapInformationBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontLightFamily: "72-Light", "72-Lightfull", "72", "72full", Arial, Helvetica, sans-serif;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontBoldFamily: "72-Bold", "72-Boldfull", "72", "72full", Arial, Helvetica, sans-serif;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontSemiboldFamily: "72-Semibold", "72-Semiboldfull", "72", "72full", Arial, Helvetica, sans-serif;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontSemiboldDuplexFamily: "72-SemiboldDuplex", "72-SemiboldDuplexfull", "72", "72full", Arial, Helvetica, sans-serif;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontBlackFamily: "72Black", "72Blackfull","72", "72full", Arial, Helvetica, sans-serif;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontHeaderFamily: @sapFontFamily;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontSmallSize: 0.75 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontLargeSize: 1.0 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontHeader1Size: 2.25 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontHeader2Size: 1.5 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontHeader3Size: 1.25 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontHeader4Size: 1.125 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontHeader5Size: 1.0 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapFontHeader6Size: 0.875 * @sapContent_GridSize;
@sapLink_TextDecoration: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLink_Hover_Color: darken(@sapLinkColor, 10);
@sapLink_Hover_TextDecoration: underline;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLink_Active_Color: @sapLinkColor;
@sapLink_Active_TextDecoration: underline;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLink_Visited_Color: @sapLinkColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLink_InvertedColor: lighten(saturate(@sapLinkColor, 6), 36);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLink_SubtleColor: lighten(@sapLinkColor, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Background: @sapPrimary4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_BackgroundImage: linear-gradient(to bottom, darken(@sapShell_Background, 5), lighten(@sapShell_Background, 2));

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_BackgroundImageOpacity: 1.0;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_BackgroundImageRepeat: false;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_BorderColor: @sapShellColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_TextColor: contrast(@sapShellColor, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_InteractiveBackground: @sapShellColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_InteractiveTextColor: #d1e8ff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_InteractiveBorderColor: lighten(@sapShellColor, 30);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_GroupTitleTextColor: @sapTitleColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_GroupTitleTextShadow: 0 0 0.125rem contrast(@sapShell_GroupTitleTextColor, @sapContent_ShadowColor, @sapContent_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Hover_Background: darken(@sapShellColor, 7);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Active_Background: darken(@sapShellColor, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Active_TextColor: contrast(@sapShell_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Selected_Background: darken(@sapShellColor, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Selected_TextColor: contrast(@sapShell_Selected_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Selected_Hover_Background: darken(@sapShellColor, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Favicon: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Navigation_Background: @sapShellColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Navigation_Hover_Background: @sapShell_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Navigation_SelectedColor: @sapShell_Navigation_Selected_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Navigation_Selected_TextColor: @sapShell_InteractiveTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Navigation_TextColor: contrast(@sapShell_Navigation_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Navigation_Active_TextColor: contrast(@sapShell_Navigation_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Navigation_Active_Background: @sapShell_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Shadow: 0 0.125rem 0.125rem 0 fade(@sapContent_ShadowColor, 80), inset 0 -0.0625rem 0 0 fade(@sapContent_ContrastShadowColor, 20);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_NegativeColor: @sapNegativeColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_CriticalColor: @sapCriticalColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_PositiveColor: @sapPositiveColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_InformativeColor: lighten(@sapInformativeColor, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_NeutralColor: @sapNeutralColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Assistant_ForegroundColor: lighten(@sapAssistant_Color1, 16);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_SubBrand_TextColor: contrast(@sapShellColor, @sapHighlightColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_1_Background: @sapLegendColor6;
@sapShell_Category_1_BorderColor: @sapShell_Category_1_Background;
@sapShell_Category_1_TextColor: contrast(@sapShell_Category_1_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_1_TextShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_2_Background: @sapLegendColor3;
@sapShell_Category_2_BorderColor: @sapShell_Category_2_Background;
@sapShell_Category_2_TextColor: contrast(@sapShell_Category_2_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_2_TextShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_3_Background: @sapLegendColor1;
@sapShell_Category_3_BorderColor: @sapShell_Category_3_Background;
@sapShell_Category_3_TextColor: contrast(@sapShell_Category_3_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_3_TextShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_4_Background: @sapLegendColor10;
@sapShell_Category_4_BorderColor: @sapShell_Category_4_Background;
@sapShell_Category_4_TextColor: contrast(@sapShell_Category_4_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_4_TextShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_5_Background: @sapLegendColor12;
@sapShell_Category_5_BorderColor: @sapShell_Category_5_Background;
@sapShell_Category_5_TextColor: contrast(@sapShell_Category_5_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_5_TextShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_6_Background: @sapLegendColor7;
@sapShell_Category_6_BorderColor: @sapShell_Category_6_Background;
@sapShell_Category_6_TextColor: contrast(@sapShell_Category_6_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_6_TextShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_7_Background: @sapLegendColor5;
@sapShell_Category_7_BorderColor: @sapShell_Category_7_Background;
@sapShell_Category_7_TextColor: contrast(@sapShell_Category_7_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_7_TextShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_8_Background: @sapLegendColor8;
@sapShell_Category_8_BorderColor: @sapShell_Category_8_Background;
@sapShell_Category_8_TextColor: contrast(@sapShell_Category_8_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_8_TextShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_9_Background: @sapLegendColor16;
@sapShell_Category_9_BorderColor: @sapShell_Category_9_Background;
@sapShell_Category_9_TextColor: contrast(@sapShell_Category_9_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_9_TextShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_10_Background: @sapLegendColor9;
@sapShell_Category_10_BorderColor: @sapShell_Category_10_Background;
@sapShell_Category_10_TextColor: contrast(@sapShell_Category_10_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_10_TextShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_11_Background: @sapLegendColor2;
@sapShell_Category_11_BorderColor: @sapShell_Category_11_Background;
@sapShell_Category_11_TextColor: contrast(@sapShell_Category_11_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_11_TextShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_12_Background: @sapLegendColor20;
@sapShell_Category_12_BorderColor: @sapShell_Category_12_Background;
@sapShell_Category_12_TextColor: contrast(@sapShell_Category_12_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_12_TextShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_13_Background: @sapLegendColor13;
@sapShell_Category_13_BorderColor: @sapShell_Category_13_Background;
@sapShell_Category_13_TextColor: contrast(@sapShell_Category_13_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_13_TextShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_14_Background: @sapLegendColor17;
@sapShell_Category_14_BorderColor: @sapShell_Category_14_Background;
@sapShell_Category_14_TextColor: contrast(@sapShell_Category_14_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_14_TextShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_15_Background: lighten(@sapLegendColor16, 15);
@sapShell_Category_15_BorderColor: @sapShell_Category_15_Background;
@sapShell_Category_15_TextColor: contrast(@sapShell_Category_15_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_15_TextShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapShell_Category_16_Background: @sapLegendColor18;
@sapShell_Category_16_BorderColor: @sapShell_Category_16_Background;
@sapShell_Category_16_TextColor: contrast(@sapShell_Category_16_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapShell_Category_16_TextShadow: none;
@sapShell_Space_S: 0.5rem;
@sapShell_Space_M: 2rem;
@sapShell_Space_L: 2rem;
@sapShell_Space_XL: 3rem;
@sapShell_Gap_S: 0.5rem;
@sapShell_Gap_M: 1rem;
@sapShell_Gap_L: 1rem;
@sapShell_Gap_XL: 1rem;
@sapShell_GroupGap_S: 2rem;
@sapShell_GroupGap_M: 3rem;
@sapShell_GroupGap_L: 3rem;
@sapShell_GroupGap_XL: 3rem;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Color1: #5d36ff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Color2: #a100c2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_BackgroundGradient: linear-gradient(@sapAssistant_Color1, @sapAssistant_Color2);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Background: @sapAssistant_Color1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_BorderColor: @sapAssistant_Color1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_TextColor: contrast(@sapAssistant_Background, lighten(@sapTextColor, 2), @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Hover_Background: darken(@sapAssistant_Color1, 20);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Hover_BorderColor: @sapAssistant_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Hover_TextColor: contrast(@sapAssistant_Hover_Background, lighten(@sapTextColor, 2), @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Active_Background: darken(@sapAssistant_Color1, 30);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Active_BorderColor: @sapAssistant_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Active_TextColor: contrast(@sapAssistant_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Question_Background: darken(@sapAssistant_Background, 40.5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Question_BorderColor: @sapAssistant_Question_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Question_TextColor: contrast(@sapAssistant_Question_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Answer_Background: darken(@sapBaseColor, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Answer_BorderColor: @sapAssistant_Answer_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAssistant_Answer_TextColor: contrast(@sapAssistant_Answer_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_1_Background: @sapAccentColor1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_1_BorderColor: @sapAccentColor1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_1_TextColor: contrast(@sapAvatar_1_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_1_Hover_Background: @sapAvatar_1_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_2_Background: @sapAccentColor2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_2_BorderColor: @sapAccentColor2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_2_TextColor: contrast(@sapAvatar_2_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_2_Hover_Background: @sapAvatar_2_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_3_Background: @sapAccentColor3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_3_BorderColor: @sapAccentColor3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_3_TextColor: contrast(@sapAvatar_3_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_3_Hover_Background: @sapAvatar_3_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_4_Background: @sapAccentColor4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_4_BorderColor: @sapAccentColor4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_4_TextColor: contrast(@sapAvatar_4_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_4_Hover_Background: @sapAvatar_4_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_5_Background: @sapAccentColor5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_5_BorderColor: @sapAccentColor5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_5_TextColor: contrast(@sapAvatar_5_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_5_Hover_Background: @sapAvatar_5_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_6_Background: @sapAccentColor6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_6_BorderColor: @sapAccentColor6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_6_TextColor: contrast(@sapAvatar_6_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_6_Hover_Background: @sapAvatar_6_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_7_Background: @sapAccentColor7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_7_BorderColor: @sapAccentColor7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_7_TextColor: contrast(@sapAvatar_7_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_7_Hover_Background: @sapAvatar_7_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_8_Background: @sapAccentColor8;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_8_BorderColor: @sapAccentColor8;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_8_TextColor: contrast(@sapAvatar_8_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_8_Hover_Background: @sapAvatar_8_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_9_Background: @sapAccentColor9;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_9_BorderColor: @sapAccentColor9;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_9_TextColor: contrast(@sapAvatar_9_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_9_Hover_Background: @sapAvatar_9_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_10_Background: @sapAccentColor10;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_10_BorderColor: @sapAccentColor10;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_10_TextColor: contrast(@sapAvatar_10_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_10_Hover_Background: @sapAvatar_10_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_Lite_BorderColor: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_Lite_Background: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAvatar_Hover_BorderColor: fade(@sapField_BorderColor, 25);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Background: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_BorderColor: @sapHighlightColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_BorderWidth: @sapElement_BorderWidth;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_BorderCornerRadius: @sapElement_BorderCornerRadius;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_TextColor: contrast(@sapButton_Background, @sapHighlightColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_FontFamily: @sapFontFamily;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Hover_Background: darken(@sapHighlightColor, 60);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Hover_BorderColor: @sapButton_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Hover_TextColor: contrast(@sapButton_Hover_Background, @sapHighlightColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_IconColor: contrast(@sapButton_Background, @sapContent_IconColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Active_Background: @sapActiveColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Active_BorderColor: @sapButton_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Active_TextColor: contrast(@sapButton_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_Background: darken(@sapBrandColor, 25);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_BorderColor: @sapButton_Emphasized_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_BorderWidth: @sapElement_BorderWidth;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_TextColor: contrast(@sapButton_Emphasized_Background, lighten(@sapTextColor, 2), @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_FontFamily: @sapFontBoldFamily;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_Hover_Background: lighten(@sapButton_Emphasized_Background, 4);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_Hover_BorderColor: @sapButton_Emphasized_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_Hover_TextColor: contrast(@sapButton_Emphasized_Hover_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_Active_Background: @sapButton_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_Active_BorderColor: @sapButton_Emphasized_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_Active_TextColor: contrast(@sapButton_Emphasized_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_TextShadow: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Emphasized_FontWeight: bold;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Background: @sapButton_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_BorderColor: @sapNegativeElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_TextColor: contrast(@sapButton_Reject_Background, @sapNegativeTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Hover_Background: @sapErrorBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Hover_BorderColor: @sapButton_Reject_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Hover_TextColor: contrast(@sapButton_Reject_Hover_Background, @sapNegativeTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Active_Background: darken(@sapNegativeElementColor, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Active_BorderColor: @sapButton_Reject_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Active_TextColor: contrast(@sapButton_Reject_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Selected_Background: @sapButton_Reject_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Selected_BorderColor: @sapButton_Reject_Selected_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Selected_TextColor: contrast(@sapButton_Reject_Selected_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Selected_Hover_Background: lighten(@sapButton_Reject_Selected_Background, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Reject_Selected_Hover_BorderColor: @sapButton_Reject_Selected_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Background: @sapButton_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_BorderColor: @sapPositiveElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_TextColor: contrast(@sapButton_Accept_Background, @sapPositiveTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Hover_Background: @sapSuccessBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Hover_BorderColor: @sapButton_Accept_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Hover_TextColor: contrast(@sapButton_Accept_Hover_Background, @sapPositiveTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Active_Background: darken(@sapPositiveElementColor, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Active_BorderColor: @sapButton_Accept_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Active_TextColor: contrast(@sapButton_Accept_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Selected_Background: @sapButton_Accept_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Selected_BorderColor: @sapButton_Accept_Selected_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Selected_TextColor: contrast(@sapButton_Accept_Selected_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Selected_Hover_Background: lighten(@sapButton_Accept_Selected_Background, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Accept_Selected_Hover_BorderColor: @sapButton_Accept_Selected_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Lite_Background: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Lite_BorderColor: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Lite_TextColor: @sapButton_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Lite_Hover_Background: @sapButton_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Lite_Hover_BorderColor: @sapButton_Hover_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Lite_Hover_TextColor: @sapButton_Lite_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Lite_Active_Background: @sapButton_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Lite_Active_BorderColor: @sapButton_Active_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Selected_Background: @sapSelectedColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Selected_BorderColor: @sapButton_Selected_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Selected_TextColor: contrast(@sapButton_Selected_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Selected_Hover_Background: darken(@sapButton_Selected_Background, 3);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Selected_Hover_BorderColor: @sapButton_Selected_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Background: @sapButton_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_BorderColor: @sapCriticalElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_TextColor: contrast(@sapButton_Attention_Background, @sapCriticalTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Hover_Background: @sapWarningBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Hover_BorderColor: @sapButton_Attention_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Hover_TextColor: contrast(@sapButton_Attention_Hover_Background, @sapCriticalTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Active_Background: darken(@sapCriticalElementColor, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Active_BorderColor: @sapButton_Attention_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Active_TextColor: contrast(@sapButton_Attention_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Selected_Background: @sapButton_Attention_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Selected_BorderColor: @sapButton_Attention_Selected_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Selected_TextColor: contrast(@sapButton_Attention_Selected_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Selected_Hover_Background: lighten(@sapButton_Attention_Selected_Background, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Attention_Selected_Hover_BorderColor: @sapButton_Attention_Selected_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Negative_Background: @sapNegativeElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Negative_BorderColor: @sapButton_Negative_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Negative_TextColor: contrast(@sapButton_Negative_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Negative_Hover_Background: lighten(@sapButton_Negative_Background, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Negative_Hover_BorderColor: @sapButton_Negative_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Negative_Hover_TextColor: contrast(@sapButton_Negative_Hover_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Negative_Active_Background: lighten(@sapButton_Negative_Background, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Negative_Active_BorderColor: @sapButton_Negative_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Negative_Active_TextColor: contrast(@sapButton_Negative_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Critical_Background: @sapCriticalElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Critical_BorderColor: @sapButton_Critical_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Critical_TextColor: contrast(@sapButton_Critical_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Critical_Hover_Background: lighten(@sapButton_Critical_Background, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Critical_Hover_BorderColor: @sapButton_Critical_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Critical_Hover_TextColor: contrast(@sapButton_Critical_Hover_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Critical_Active_Background: lighten(@sapButton_Critical_Background, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Critical_Active_BorderColor: @sapButton_Critical_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Critical_Active_TextColor: contrast(@sapButton_Critical_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Success_Background: @sapPositiveElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Success_BorderColor: @sapButton_Success_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Success_TextColor: contrast(@sapButton_Success_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Success_Hover_Background: lighten(@sapButton_Success_Background, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Success_Hover_BorderColor: @sapButton_Success_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Success_Hover_TextColor: contrast(@sapButton_Success_Hover_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Success_Active_Background: lighten(@sapButton_Success_Background, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Success_Active_BorderColor: @sapButton_Success_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Success_Active_TextColor: contrast(@sapButton_Success_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Information_Background: @sapInformativeElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Information_BorderColor: @sapButton_Information_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Information_TextColor: contrast(@sapButton_Information_Background,@sapTextColor,@sapContent_ContrastTextColor,@sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Information_Hover_Background: lighten(@sapButton_Information_Background, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Information_Hover_BorderColor: @sapButton_Information_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Information_Hover_TextColor: contrast(@sapButton_Information_Hover_Background,@sapTextColor,@sapContent_ContrastTextColor,@sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Information_Active_Background: lighten(@sapButton_Information_Background, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Information_Active_BorderColor: @sapButton_Information_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Information_Active_TextColor: contrast(@sapButton_Information_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Neutral_Background: @sapNeutralElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Neutral_BorderColor: @sapButton_Neutral_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Neutral_TextColor: contrast(@sapButton_Neutral_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Neutral_Hover_Background: lighten(@sapButton_Neutral_Background, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Neutral_Hover_BorderColor: @sapButton_Neutral_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Neutral_Hover_TextColor: contrast(@sapButton_Neutral_Hover_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Neutral_Active_Background: lighten(@sapButton_Neutral_Background, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Neutral_Active_BorderColor: @sapButton_Neutral_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Neutral_Active_TextColor: contrast(@sapButton_Neutral_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Background: lighten(@sapButton_Background, 7);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_BorderColor: @sapContent_ForegroundBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_TextColor: contrast(@sapButton_Track_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Hover_Background: @sapButton_Track_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Hover_BorderColor: @sapButton_Hover_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Selected_Background: darken(@sapButton_Selected_Background, 60);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Selected_BorderColor: @sapButton_Selected_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Selected_TextColor: contrast(@sapButton_Track_Selected_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Selected_Hover_Background: @sapButton_Track_Selected_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Selected_Hover_BorderColor: @sapButton_Selected_Hover_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Background: @sapButton_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_BorderColor: @sapContent_ForegroundBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_TextColor: contrast(@sapButton_Handle_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Hover_Background: @sapButton_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Hover_BorderColor: @sapButton_Hover_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Selected_Background: @sapButton_Selected_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Selected_BorderColor: @sapButton_Selected_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Selected_TextColor: contrast(@sapButton_Handle_Selected_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Selected_Hover_Background: @sapButton_Selected_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Selected_Hover_BorderColor: @sapButton_Selected_Hover_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Negative_Background: @sapErrorBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Negative_BorderColor: @sapErrorBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Negative_TextColor: contrast(@sapButton_Track_Negative_Background, @sapNegativeElementColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Negative_Hover_Background: @sapButton_Track_Negative_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Negative_Hover_BorderColor: @sapButton_Track_Negative_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Negative_Background: @sapButton_Handle_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Negative_BorderColor: @sapErrorBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Negative_TextColor: contrast(@sapButton_Handle_Negative_Background, @sapNegativeElementColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Negative_Hover_Background: @sapErrorBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Negative_Hover_BorderColor: @sapButton_Handle_Negative_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Positive_Background: @sapSuccessBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Positive_BorderColor: @sapSuccessBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Positive_TextColor: contrast(@sapButton_Track_Positive_Background, @sapPositiveElementColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Positive_Hover_Background: @sapButton_Track_Positive_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Track_Positive_Hover_BorderColor: @sapButton_Track_Positive_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Positive_Background: @sapButton_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Positive_BorderColor: @sapSuccessBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Positive_TextColor: contrast(@sapButton_Handle_Positive_Background, @sapPositiveTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Positive_Hover_Background: @sapSuccessBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Handle_Positive_Hover_BorderColor: @sapButton_Handle_Positive_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_TokenBackground: @sapButton_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_TokenBorderColor: lighten(@sapButton_Background, 30);

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_TokenBorderCornerRadius: 0.25 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Selected_TokenBorderWidth: 0;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_ReadOnly_TokenBackground: @sapField_ReadOnly_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapButton_Segment_BorderCornerRadius: 0;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Background: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_BackgroundStyle: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_TextColor: @sapTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_PlaceholderTextColor: darken(@sapContent_LabelColor, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_BorderColor: @sapPrimary5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_HelpBackground: @sapField_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_BorderWidth: @sapElement_BorderWidth;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_BorderStyle: solid;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_BorderCornerRadius: 0.125 * @sapContent_GridSize;
@sapField_Shadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Hover_Background: @sapField_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Hover_BackgroundStyle: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Hover_BorderColor: @sapHighlightColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Hover_HelpBackground: @sapButton_Hover_Background;
@sapField_Hover_Shadow: none;
@sapField_Hover_InvalidShadow: @sapField_InvalidShadow;
@sapField_Hover_WarningShadow: @sapField_WarningShadow;
@sapField_Hover_SuccessShadow: @sapField_SuccessShadow;
@sapField_Hover_InformationShadow: @sapField_InformationShadow;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Active_BorderColor: @sapActiveColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Focus_Background: @sapField_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Focus_BorderColor: @sapContent_FocusColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Focus_HelpBackground: @sapField_Focus_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_ReadOnly_Background: lighten(@sapField_Background, 8);

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_ReadOnly_BackgroundStyle: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_ReadOnly_BorderColor: darken(@sapField_BorderColor, 20);

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_ReadOnly_BorderStyle: @sapField_BorderStyle;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_ReadOnly_HelpBackground: @sapField_ReadOnly_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_RequiredColor: @sapAccentColor2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InvalidColor: @sapErrorBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InvalidBackground: @sapField_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InvalidBackgroundStyle: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InvalidBorderWidth: 0.125 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InvalidBorderStyle: solid;
@sapField_InvalidShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_WarningColor: @sapWarningBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_WarningBackground: @sapField_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_WarningBackgroundStyle: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_WarningBorderWidth: 0.125 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_WarningBorderStyle: solid;
@sapField_WarningShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_SuccessColor: @sapSuccessBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_SuccessBackground: @sapField_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_SuccessBackgroundStyle: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_SuccessBorderWidth: 0.0625 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_SuccessBorderStyle: solid;
@sapField_SuccessShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InformationColor: @sapInformationBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InformationBackground: @sapField_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InformationBackgroundStyle: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InformationBorderWidth: 0.125 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_InformationBorderStyle: solid;
@sapField_InformationShadow: none;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_Hover_Background: @sapField_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_Hover_InvalidBackground: @sapField_InvalidBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_Hover_WarningBackground: @sapField_WarningBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_Hover_SuccessBackground: @sapField_SuccessBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_Hover_InformationBackground: @sapField_InformationBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Picker_BorderColor: @sapField_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Picker_BorderWidth: 0.0625 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_BorderStyle: solid;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_ReadOnly_BorderStyle: solid;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_InvalidBorderStyle: solid;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_WarningBorderStyle: solid;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_SuccessBorderStyle: solid;

// [Tags "!Protected"]
// [Protected "!true"]
@sapField_Selector_InformationBorderStyle: solid;

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_TitleBorderWidth: @sapElement_BorderWidth;

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_TitleBackground: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_TitleBorderColor: lighten(@sapBaseColor, 15);

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_TitleTextColor: contrast(@sapBackgroundColor, @sapTitleColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_Title_FontSize: @sapFontHeader4Size;

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_ContentBackground: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_ContentBorderColor: lighten(@sapGroup_ContentBackground, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_BorderWidth: @sapElement_BorderWidth;

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_BorderCornerRadius: 0;

// [Tags "!Protected"]
// [Protected "!true"]
@sapGroup_FooterBackground: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapToolbar_Background: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapToolbar_SeparatorColor: lighten(@sapBaseColor, 15);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_HeaderBackground: darken(@sapList_Background, 3);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_HeaderBorderColor: @sapList_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_HeaderTextColor: contrast(@sapList_HeaderBackground, @sapTitleColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_BorderColor: lighten(@sapList_Background, 8);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_BorderWidth: @sapElement_BorderWidth;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_TextColor: contrast(@sapList_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_Active_TextColor: contrast(@sapList_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_Active_Background: @sapActiveColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_SelectionBackgroundColor: darken(desaturate(@sapSelectedColor, 55), 48);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_SelectionBorderColor: @sapSelectedColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_Hover_SelectionBackground: contrast(@sapList_SelectionBackgroundColor, darken(@sapList_SelectionBackgroundColor, 3), lighten(@sapList_SelectionBackgroundColor, 3));

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_Background: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_Hover_Background: contrast(@sapList_Background, darken(@sapList_Background, 4), @sapHoverColor);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_AlternatingBackground: darken(@sapList_Background, 3);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_GroupHeaderBackground: @sapList_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_GroupHeaderBorderColor: lighten(@sapList_BorderColor, 20);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_GroupHeaderTextColor: contrast(@sapList_GroupHeaderBackground, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_TableGroupHeaderBackground: darken(@sapList_Background, 6.1);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_TableGroupHeaderBorderColor: lighten(@sapList_BorderColor, 15);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_TableGroupHeaderTextColor: contrast(@sapList_TableGroupHeaderBackground, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_FooterBackground: darken(@sapList_Background, 2);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_FooterTextColor: contrast(@sapList_FooterBackground, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_TableFooterBorder: lighten(@sapList_BorderColor, 8);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_TableFixedBorderColor: lighten(@sapList_BorderColor, 30);

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_TableFixedColumnBorderWidth: @sapElement_BorderWidth;

// [Tags "!Protected"]
// [Protected "!true"]
@sapList_TableFixedRowBorderWidth: 0.125 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapMessage_BorderWidth: @sapElement_BorderWidth;

// [Tags "!Protected"]
// [Protected "!true"]
@sapMessage_ErrorBorderColor: @sapErrorBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapMessage_WarningBorderColor: @sapWarningBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapMessage_SuccessBorderColor: @sapSuccessBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapMessage_InformationBorderColor: @sapInformationBorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapMessage_Button_Hover_Background: fade(@sapButton_Lite_Hover_Background, 20);

// [Tags "!Protected"]
// [Protected "!true"]
@sapPopover_BorderCornerRadius: @sapElement_BorderCornerRadius;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Background: @sapField_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_BorderColor: @sapField_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_TextColor: contrast(@sapProgress_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_FontSize: @sapFontSmallSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_NegativeBackground: @sapProgress_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_NegativeBorderColor: @sapProgress_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_NegativeTextColor: contrast(@sapProgress_NegativeBackground, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_CriticalBackground: @sapProgress_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_CriticalBorderColor: @sapProgress_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_CriticalTextColor: contrast(@sapProgress_CriticalBackground, @sapProgress_TextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_PositiveBackground: @sapProgress_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_PositiveBorderColor: @sapProgress_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_PositiveTextColor: contrast(@sapProgress_PositiveBackground, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_InformationBackground: @sapProgress_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_InformationBorderColor: @sapProgress_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_InformationTextColor: contrast(@sapProgress_InformationBackground, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_Background: @sapNeutralElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_BorderColor: @sapProgress_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_TextColor: contrast(@sapProgress_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_NegativeBackground: @sapNegativeElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_NegativeBorderColor: @sapProgress_NegativeBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_NegativeTextColor: contrast(@sapProgress_NegativeBackground, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_CriticalBackground: @sapCriticalElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_CriticalBorderColor: @sapProgress_CriticalBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_CriticalTextColor: contrast(@sapProgress_CriticalBackground, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_PositiveBackground: @sapPositiveElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_PositiveBorderColor: @sapProgress_PositiveBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_PositiveTextColor: contrast(@sapProgress_PositiveBackground, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_InformationBackground: @sapInformativeElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_InformationBorderColor: @sapProgress_InformationBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapProgress_Value_InformationTextColor: contrast(@sapProgress_InformationBackground, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapScrollBar_FaceColor: lighten(@sapScrollBar_TrackColor, 34);

// [Tags "!Protected"]
// [Protected "!true"]
@sapScrollBar_TrackColor: darken(@sapBaseColor, 15);

// [Tags "!Protected"]
// [Protected "!true"]
@sapScrollBar_BorderColor: @sapScrollBar_FaceColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapScrollBar_SymbolColor: @sapContent_IconColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapScrollBar_Dimension: 0.75 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapScrollBar_Hover_FaceColor: darken(@sapScrollBar_FaceColor, 3);

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_Background: @sapField_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_BorderColor: @sapSlider_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_Selected_Background: @sapActiveColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_Selected_BorderColor: @sapSlider_Selected_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_HandleBackground: @sapButton_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_HandleBorderColor: @sapField_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_RangeHandleBackground: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_Hover_HandleBackground: @sapButton_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_Hover_HandleBorderColor: @sapButton_Hover_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_Hover_RangeHandleBackground: @sapSlider_Hover_HandleBackground;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_Active_HandleBackground: @sapButton_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_Active_HandleBorderColor: @sapButton_Active_BorderColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapSlider_Active_RangeHandleBackground: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapPageHeader_Background: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapPageHeader_BorderColor: lighten(@sapPageHeader_Background, 8);

// [Tags "!Protected"]
// [Protected "!true"]
@sapPageHeader_TextColor: contrast(@sapPageHeader_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapPageFooter_Background: lighten(saturate(@sapBaseColor, 11.7), 4.75);

// [Tags "!Protected"]
// [Protected "!true"]
@sapPageFooter_BorderColor: lighten(@sapPageFooter_Background, 8);

// [Tags "!Protected"]
// [Protected "!true"]
@sapPageFooter_TextColor: contrast(@sapPageFooter_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapInfobar_Background: @sapAccentColor7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapInfobar_Hover_Background: darken(@sapInfobar_Background, 3);

// [Tags "!Protected"]
// [Protected "!true"]
@sapInfobar_Active_Background: darken(@sapInfobar_Background, 11);

// [Tags "!Protected"]
// [Protected "!true"]
@sapInfobar_NonInteractive_Background: darken(@sapList_Background, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapInfobar_TextColor: contrast(@sapInfobar_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapObjectHeader_Background: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapObjectHeader_Hover_Background: contrast(@sapObjectHeader_Background, darken(@sapObjectHeader_Background, 4), @sapHoverColor);

// [Tags "!Protected"]
// [Protected "!true"]
@sapObjectHeader_BorderColor: lighten(@sapObjectHeader_Background, 8);

// [Tags "!Protected"]
// [Protected "!true"]
@sapObjectHeader_Title_TextColor: contrast(@sapObjectHeader_Background, @sapTitleColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapObjectHeader_Title_FontSize: @sapFontHeader3Size;

// [Tags "!Protected"]
// [Protected "!true"]
@sapObjectHeader_Title_SnappedFontSize: @sapFontHeader3Size;

// [Tags "!Protected"]
// [Protected "!true"]
@sapObjectHeader_Title_FontFamily: @sapFontFamily;

// [Tags "!Protected"]
// [Protected "!true"]
@sapObjectHeader_Subtitle_TextColor: contrast(@sapObjectHeader_Background, @sapContent_LabelColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapBlockLayer_Background: #000;

// [Tags "!Protected"]
// [Protected "!true"]
@sapBlockLayer_Opacity: 0.2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_TextColor: @sapContent_LabelColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_ForegroundColor: @sapHighlightColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_IconColor: contrast(@sapTab_Background, @sapHighlightColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Background: @sapObjectHeader_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Selected_TextColor: @sapContent_Selected_ForegroundColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Selected_IconColor: contrast(@sapTab_Selected_Background, @sapContent_Selected_ForegroundColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Selected_Background: @sapSelectedColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Selected_Indicator_Dimension: 0.1875 * @sapContent_GridSize;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Positive_TextColor: @sapPositiveTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Positive_ForegroundColor: @sapPositiveElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Positive_IconColor: contrast(@sapTab_Background, @sapPositiveElementColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Positive_Selected_TextColor: @sapPositiveTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Positive_Selected_IconColor: contrast(@sapTab_Positive_Selected_Background, @sapTextColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Positive_Selected_Background: @sapPositiveElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Negative_TextColor: @sapNegativeTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Negative_ForegroundColor: @sapNegativeElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Negative_IconColor: contrast(@sapTab_Background, @sapNegativeElementColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Negative_Selected_TextColor: @sapNegativeTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Negative_Selected_IconColor: contrast(@sapTab_Negative_Selected_Background, @sapTextColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Negative_Selected_Background: @sapNegativeElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Critical_TextColor: @sapCriticalTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Critical_ForegroundColor: @sapCriticalElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Critical_IconColor: contrast(@sapTab_Background, @sapCriticalElementColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Critical_Selected_TextColor: @sapCriticalTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Critical_Selected_IconColor: contrast(@sapTab_Critical_Selected_Background, @sapTextColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Critical_Selected_Background: @sapCriticalElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Neutral_TextColor: @sapNeutralTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Neutral_ForegroundColor: @sapNeutralElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Neutral_IconColor: contrast(@sapTab_Background, @sapNeutralElementColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Neutral_Selected_TextColor: @sapNeutralTextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Neutral_Selected_IconColor: contrast(@sapTab_Neutral_Selected_Background, @sapTextColor, @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTab_Neutral_Selected_Background: @sapNeutralElementColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_Background: @sapBaseColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_Hover_Background: darken(@sapTile_Background, 4);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_Active_Background: darken(@sapTile_Background, 4);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_BorderColor: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_BorderCornerRadius: @sapElement_BorderCornerRadius;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_TitleTextColor: contrast(@sapTile_Background, @sapTitleColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_TextColor: contrast(@sapTile_Background, @sapContent_LabelColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_IconColor: contrast(@sapTile_Background, lighten(@sapShellColor, 35), @sapContent_ContrastIconColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_SeparatorColor: lighten(@sapTile_Background, 12);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_Interactive_BorderColor: lighten(@sapTile_Background, 30);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_OverlayBackground: fade(@sapBlockLayer_Background, 80);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_OverlayForegroundColor: contrast(@sapTile_OverlayBackground, @sapTitleColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_Hover_ContentBackground: @sapTile_Hover_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapTile_Active_ContentBackground: @sapTile_Active_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor1: #ffc847;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor2: #e7a1a1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor3: #f37aa2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor4: #e269c9;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor5: #8ca7d5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor6: #6bd3ff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor7: #7fc6c6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor8: #b2e484;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor9: #b995e0;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentColor10: #b0bcc5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor1: #fff3b8;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor2: #ffd0e7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor3: #fff0fa;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor4: #ffdcf3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor5: #ded3ff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor6: #d1efff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor7: #c2fcee;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor8: #ebf5cb;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor9: #dafdf5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapAccentBackgroundColor10: #eaecee;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_1: #ff5555;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_1_Background: @sapIndicationColor_1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_1_BorderColor: @sapIndicationColor_1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_1_TextColor: contrast(@sapIndicationColor_1_Background, @sapTextColor, @sapContent_ContrastTextColor, 0.47);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_1_Hover_Background: lighten(@sapIndicationColor_1, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_1_Active_Background: lighten(@sapIndicationColor_1, 10);
@sapIndicationColor_1_Active_BorderColor: @sapIndicationColor_1_BorderColor;
@sapIndicationColor_1_Active_TextColor: contrast(@sapIndicationColor_1_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapIndicationColor_1_Selected_Background: @sapIndicationColor_1_Active_Background;
@sapIndicationColor_1_Selected_BorderColor: @sapIndicationColor_1_Active_BorderColor;
@sapIndicationColor_1_Selected_TextColor: @sapIndicationColor_1_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_1b: #5e0303;
@sapIndicationColor_1b_TextColor: lighten(saturate(@sapIndicationColor_1b, 4), 44);
@sapIndicationColor_1b_Background: @sapIndicationColor_1b;
@sapIndicationColor_1b_BorderColor: @sapIndicationColor_1b;
@sapIndicationColor_1b_Hover_Background: lighten(@sapIndicationColor_1b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_2: #ff8888;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_2_Background: @sapIndicationColor_2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_2_BorderColor: @sapIndicationColor_2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_2_TextColor: contrast(@sapIndicationColor_2_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_2_Hover_Background: lighten(@sapIndicationColor_2, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_2_Active_Background: lighten(@sapIndicationColor_2, 10);
@sapIndicationColor_2_Active_BorderColor: @sapIndicationColor_2_BorderColor;
@sapIndicationColor_2_Active_TextColor: contrast(@sapIndicationColor_2_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapIndicationColor_2_Selected_Background: @sapIndicationColor_2_Active_Background;
@sapIndicationColor_2_Selected_BorderColor: @sapIndicationColor_2_Active_BorderColor;
@sapIndicationColor_2_Selected_TextColor: @sapIndicationColor_2_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_2b: #7d0000;
@sapIndicationColor_2b_TextColor: lighten(@sapIndicationColor_2b, 53);
@sapIndicationColor_2b_Background: @sapIndicationColor_2b;
@sapIndicationColor_2b_BorderColor: @sapIndicationColor_2b;
@sapIndicationColor_2b_Hover_Background: lighten(@sapIndicationColor_2b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_3: #fabd64;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_3_Background: @sapIndicationColor_3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_3_BorderColor: @sapIndicationColor_3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_3_TextColor: contrast(@sapIndicationColor_3_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_3_Hover_Background: lighten(@sapIndicationColor_3, 3);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_3_Active_Background: lighten(@sapIndicationColor_3, 6);
@sapIndicationColor_3_Active_BorderColor: @sapIndicationColor_3_BorderColor;
@sapIndicationColor_3_Active_TextColor: contrast(@sapIndicationColor_3_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapIndicationColor_3_Selected_Background: @sapIndicationColor_3_Active_Background;
@sapIndicationColor_3_Selected_BorderColor: @sapIndicationColor_3_Active_BorderColor;
@sapIndicationColor_3_Selected_TextColor: @sapIndicationColor_3_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_3b: #640;
@sapIndicationColor_3b_TextColor: lighten(@sapIndicationColor_3b, 40);
@sapIndicationColor_3b_Background: @sapIndicationColor_3b;
@sapIndicationColor_3b_BorderColor: @sapIndicationColor_3b;
@sapIndicationColor_3b_Hover_Background: lighten(@sapIndicationColor_3b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_4: #abe2ab;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_4_Background: @sapIndicationColor_4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_4_BorderColor: @sapIndicationColor_4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_4_TextColor: contrast(@sapIndicationColor_4_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_4_Hover_Background: lighten(@sapIndicationColor_4, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_4_Active_Background: lighten(@sapIndicationColor_4, 10);
@sapIndicationColor_4_Active_BorderColor: @sapIndicationColor_4_BorderColor;
@sapIndicationColor_4_Active_TextColor: contrast(@sapIndicationColor_4_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapIndicationColor_4_Selected_Background: @sapIndicationColor_4_Active_Background;
@sapIndicationColor_4_Selected_BorderColor: @sapIndicationColor_4_Active_BorderColor;
@sapIndicationColor_4_Selected_TextColor: @sapIndicationColor_4_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_4b: #1b4a04;
@sapIndicationColor_4b_TextColor: lighten(desaturate(@sapIndicationColor_4b, 21), 57);
@sapIndicationColor_4b_Background: @sapIndicationColor_4b;
@sapIndicationColor_4b_BorderColor: @sapIndicationColor_4b;
@sapIndicationColor_4b_Hover_Background: lighten(@sapIndicationColor_4b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_5: #91c8f6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_5_Background: @sapIndicationColor_5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_5_BorderColor: @sapIndicationColor_5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_5_TextColor: contrast(@sapIndicationColor_5_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_5_Hover_Background: lighten(@sapIndicationColor_5, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_5_Active_Background: lighten(@sapIndicationColor_5, 10);
@sapIndicationColor_5_Active_BorderColor: @sapIndicationColor_5_BorderColor;
@sapIndicationColor_5_Active_TextColor: contrast(@sapIndicationColor_5_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapIndicationColor_5_Selected_Background: @sapIndicationColor_5_Active_Background;
@sapIndicationColor_5_Selected_BorderColor: @sapIndicationColor_5_Active_BorderColor;
@sapIndicationColor_5_Selected_TextColor: @sapIndicationColor_5_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_5b: #024594;
@sapIndicationColor_5b_TextColor: lighten(saturate(@sapIndicationColor_5b, 3), 54);
@sapIndicationColor_5b_Background: @sapIndicationColor_5b;
@sapIndicationColor_5b_BorderColor: @sapIndicationColor_5b;
@sapIndicationColor_5b_Hover_Background: lighten(@sapIndicationColor_5b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_6: #7fc6c6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_6_Background: @sapIndicationColor_6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_6_BorderColor: @sapIndicationColor_6;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_6_TextColor: contrast(@sapIndicationColor_6_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_6_Hover_Background: lighten(@sapIndicationColor_6, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_6_Active_Background: lighten(@sapIndicationColor_6, 10);
@sapIndicationColor_6_Active_BorderColor: @sapIndicationColor_6_BorderColor;
@sapIndicationColor_6_Active_TextColor: contrast(@sapIndicationColor_6_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapIndicationColor_6_Selected_Background: @sapIndicationColor_6_Active_Background;
@sapIndicationColor_6_Selected_BorderColor: @sapIndicationColor_6_Active_BorderColor;
@sapIndicationColor_6_Selected_TextColor: @sapIndicationColor_6_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_6b: #00454e;
@sapIndicationColor_6b_TextColor: lighten(desaturate(@sapIndicationColor_6b, 21), 51);
@sapIndicationColor_6b_Background: @sapIndicationColor_6b;
@sapIndicationColor_6b_BorderColor: @sapIndicationColor_6b;
@sapIndicationColor_6b_Hover_Background: lighten(@sapIndicationColor_6b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_7: #b995e0;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_7_Background: @sapIndicationColor_7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_7_BorderColor: @sapIndicationColor_7;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_7_TextColor: contrast(@sapIndicationColor_7_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_7_Hover_Background: lighten(@sapIndicationColor_7, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_7_Active_Background: lighten(@sapIndicationColor_7, 10);
@sapIndicationColor_7_Active_BorderColor: @sapIndicationColor_7_BorderColor;
@sapIndicationColor_7_Active_TextColor: contrast(@sapIndicationColor_7_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapIndicationColor_7_Selected_Background: @sapIndicationColor_7_Active_Background;
@sapIndicationColor_7_Selected_BorderColor: @sapIndicationColor_7_Active_BorderColor;
@sapIndicationColor_7_Selected_TextColor: @sapIndicationColor_7_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_7b: #2702c2;
@sapIndicationColor_7b_TextColor: lighten(saturate(@sapIndicationColor_7b, 12), 48);
@sapIndicationColor_7b_Background: @sapIndicationColor_7b;
@sapIndicationColor_7b_BorderColor: @sapIndicationColor_7b;
@sapIndicationColor_7b_Hover_Background: lighten(@sapIndicationColor_7b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_8: #e269c9;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_8_Background: @sapIndicationColor_8;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_8_BorderColor: @sapIndicationColor_8;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_8_TextColor: contrast(@sapIndicationColor_8_Background, @sapTextColor, @sapContent_ContrastTextColor, 0.47);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_8_Hover_Background: lighten(@sapIndicationColor_8, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_8_Active_Background: lighten(@sapIndicationColor_8, 10);
@sapIndicationColor_8_Active_BorderColor: @sapIndicationColor_8_BorderColor;
@sapIndicationColor_8_Active_TextColor: contrast(@sapIndicationColor_8_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapIndicationColor_8_Selected_Background: @sapIndicationColor_8_Active_Background;
@sapIndicationColor_8_Selected_BorderColor: @sapIndicationColor_8_Active_BorderColor;
@sapIndicationColor_8_Selected_TextColor: @sapIndicationColor_8_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_8b: #4c005b;
@sapIndicationColor_8b_TextColor: lighten(@sapIndicationColor_8b, 59);
@sapIndicationColor_8b_Background: @sapIndicationColor_8b;
@sapIndicationColor_8b_BorderColor: @sapIndicationColor_8b;
@sapIndicationColor_8b_Hover_Background: lighten(@sapIndicationColor_8b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_9: #f2f2f2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_9_Background: @sapIndicationColor_9;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_9_BorderColor: @sapIndicationColor_9;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_9_TextColor: contrast(@sapIndicationColor_9_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_9_Hover_Background: lighten(@sapIndicationColor_9, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_9_Active_Background: lighten(@sapIndicationColor_9, 10);
@sapIndicationColor_9_Active_BorderColor: @sapIndicationColor_9_BorderColor;
@sapIndicationColor_9_Active_TextColor: contrast(@sapIndicationColor_9_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapIndicationColor_9_Selected_Background: @sapIndicationColor_9_Active_Background;
@sapIndicationColor_9_Selected_BorderColor: @sapIndicationColor_9_Active_BorderColor;
@sapIndicationColor_9_Selected_TextColor: @sapIndicationColor_9_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_9b: #1d232a;
@sapIndicationColor_9b_TextColor: lighten(desaturate(@sapIndicationColor_9b, 18), 81);
@sapIndicationColor_9b_Background: @sapIndicationColor_9b;
@sapIndicationColor_9b_BorderColor: lighten(@sapIndicationColor_9b, 16);
@sapIndicationColor_9b_Hover_Background: lighten(@sapIndicationColor_9b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_10: #d8d8d8;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_10_Background: @sapIndicationColor_10;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_10_BorderColor: @sapIndicationColor_10;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_10_TextColor: contrast(@sapIndicationColor_10_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_10_Hover_Background: lighten(@sapIndicationColor_10, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_10_Active_Background: lighten(@sapIndicationColor_10, 10);
@sapIndicationColor_10_Active_BorderColor: @sapIndicationColor_10_BorderColor;
@sapIndicationColor_10_Active_TextColor: contrast(@sapIndicationColor_10_Active_Background, @sapTextColor, @sapContent_ContrastTextColor, @sapContent_ContrastTextThreshold);
@sapIndicationColor_10_Selected_Background: @sapIndicationColor_10_Active_Background;
@sapIndicationColor_10_Selected_BorderColor: @sapIndicationColor_10_Active_BorderColor;
@sapIndicationColor_10_Selected_TextColor: @sapIndicationColor_10_Active_TextColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapIndicationColor_10b: #373737;
@sapIndicationColor_10b_TextColor: lighten(@sapIndicationColor_10b, 63);
@sapIndicationColor_10b_Background: @sapIndicationColor_10b;
@sapIndicationColor_10b_BorderColor: @sapIndicationColor_10b;
@sapIndicationColor_10b_Hover_Background: lighten(@sapIndicationColor_10b, 5);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegend_WorkingBackground: lighten(@sapList_Background, 2);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegend_NonWorkingBackground: lighten(@sapList_Background, 13);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegend_CurrentDateTime: @sapAccentColor4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor1: #f0b25f;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor2: #f58c4b;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor3: #d88b8b;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor4: #bd8969;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor5: #de54c1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor6: #6bd3ff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor7: #21c4c4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor8: #afd645;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor9: #b0bcc5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor10: #bb8aaf;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor11: #d1b575;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor12: #ffb98d;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor13: #ffa1a1;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor14: #d5b39e;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor15: #b7a8b3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor16: #bbbcd2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor17: #a2c2c2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor18: #aabc78;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor19: #a9d4ff;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendColor20: #c3c5fd;

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor1: darken(@sapLegendColor1, 52);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor2: darken(@sapLegendColor2, 49);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor3: darken(@sapLegendColor3, 56);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor4: darken(@sapLegendColor4, 44);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor5: darken(@sapLegendColor5, 46);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor6: darken(@sapLegendColor6, 57);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor7: darken(@sapLegendColor7, 31);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor8: darken(@sapLegendColor8, 41);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor9: darken(@sapLegendColor9, 59);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor10: darken(@sapLegendColor10, 50);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor11: darken(@sapLegendColor11, 50);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor12: darken(@sapLegendColor12, 64);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor13: darken(@sapLegendColor13, 68);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor14: darken(@sapLegendColor14, 59);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor15: darken(@sapLegendColor15, 55);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor16: darken(@sapLegendColor16, 64);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor17: darken(@sapLegendColor17, 56);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor18: darken(@sapLegendColor18, 46);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor19: darken(@sapLegendColor19, 69);

// [Tags "!Protected"]
// [Protected "!true"]
@sapLegendBackgroundColor20: darken(@sapLegendColor20, 74);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Background: transparent;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_ContrastTextShadow: 0 0 .125rem @sapContent_ContrastShadowColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_ContrastShadowColor: @sapContent_ContrastShadowColor;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_ContrastLineColor: darken(@sapGroup_ContentBackground, 20);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_LineColor_1: darken(@sapContent_ForegroundBorderColor, 35);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_LineColor_2: darken(@sapChart_LineColor_1, 32);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_LineColor_3: lighten(@sapChart_LineColor_1, 76);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Choropleth_Background: @sapChart_Sequence_Neutral_Minus5;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_ChoroplethRegion_Background: @sapChart_Sequence_Neutral;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_ChoroplethRegion_BorderColor: @sapChart_Choropleth_Background;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Data_TextColor: lighten(@sapTextColor, 2);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Data_ContrastTextColor: darken(@sapContent_ContrastTextColor, 20);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Data_InteractiveColor: @sapChart_LineColor_3;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Data_Active_Background: darken(@sapHoverColor, 10);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_1: #5899da;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_2: #e66729;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_3: #16976c;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_4: #ed4a7b;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_5: #945ecf;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_6: #1193a2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_7: #525df4;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_8: #bf399e;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_9: #6c8893;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_10: #ed5f5f;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_11: #4d78a2;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_OrderedColor_12: #a68a5b;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Bad: #dc0d0e;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Critical: #cb7d0c;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Good: #3c9d57;

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Neutral: #848f94;
@sapChart_Sequence_1_Plus3: lighten(saturate(@sapChart_Sequence_1, 13), 23);
@sapChart_Sequence_1_Plus3_TextColor: contrast(@sapChart_Sequence_1_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_1_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_1_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_1_Plus2: lighten(saturate(@sapChart_Sequence_1, 5), 15);
@sapChart_Sequence_1_Plus2_TextColor: contrast(@sapChart_Sequence_1_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_1_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_1_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_1_Plus1: lighten(saturate(@sapChart_Sequence_1, 2), 7);
@sapChart_Sequence_1_Plus1_TextColor: contrast(@sapChart_Sequence_1_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_1_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_1_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_1: @sapChart_OrderedColor_1;
@sapChart_Sequence_1_TextColor: contrast(@sapChart_Sequence_1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_1_BorderColor: @sapChart_Sequence_1;
@sapChart_Sequence_1_Minus1: darken(desaturate(@sapChart_Sequence_1, 7), 11);
@sapChart_Sequence_1_Minus1_TextColor: contrast(@sapChart_Sequence_1_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_1_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_1_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_1_Minus2: darken(saturate(@sapChart_Sequence_1, 13), 20);
@sapChart_Sequence_1_Minus2_TextColor: contrast(@sapChart_Sequence_1_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_1_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_1_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_1_Minus3: darken(saturate(@sapChart_Sequence_1, 13), 24);
@sapChart_Sequence_1_Minus3_TextColor: contrast(@sapChart_Sequence_1_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_1_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_1_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_1_Minus4: darken(saturate(@sapChart_Sequence_1, 13), 28);
@sapChart_Sequence_1_Minus4_TextColor: contrast(@sapChart_Sequence_1_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_1_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_1_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_1_Minus5: darken(saturate(@sapChart_Sequence_1, 13), 32);
@sapChart_Sequence_1_Minus5_TextColor: contrast(@sapChart_Sequence_1_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_1_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_1_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_2_Plus3: lighten(saturate(@sapChart_Sequence_2, 21), 20);
@sapChart_Sequence_2_Plus3_TextColor: contrast(@sapChart_Sequence_2_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_2_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_2_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_2_Plus2: lighten(saturate(@sapChart_Sequence_2, 10), 15);
@sapChart_Sequence_2_Plus2_TextColor: contrast(@sapChart_Sequence_2_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_2_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_2_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_2_Plus1: lighten(saturate(@sapChart_Sequence_2, 5), 7);
@sapChart_Sequence_2_Plus1_TextColor: contrast(@sapChart_Sequence_2_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_2_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_2_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_2: @sapChart_OrderedColor_2;
@sapChart_Sequence_2_TextColor: contrast(@sapChart_Sequence_2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_2_BorderColor: @sapChart_Sequence_2;
@sapChart_Sequence_2_Minus1: darken(desaturate(@sapChart_Sequence_2, 1), 9);
@sapChart_Sequence_2_Minus1_TextColor: contrast(@sapChart_Sequence_2_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_2_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_2_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_2_Minus2: darken(saturate(@sapChart_Sequence_2, 21), 17);
@sapChart_Sequence_2_Minus2_TextColor: contrast(@sapChart_Sequence_2_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_2_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_2_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_2_Minus3: darken(@sapChart_Sequence_2, 20);
@sapChart_Sequence_2_Minus3_TextColor: contrast(@sapChart_Sequence_2_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_2_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_2_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_2_Minus4: darken(@sapChart_Sequence_2, 25);
@sapChart_Sequence_2_Minus4_TextColor: contrast(@sapChart_Sequence_2_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_2_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_2_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_2_Minus5: darken(@sapChart_Sequence_2, 30);
@sapChart_Sequence_2_Minus5_TextColor: contrast(@sapChart_Sequence_2_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_2_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_2_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_3_Plus3: lighten(desaturate(@sapChart_Sequence_3, 32), 31);
@sapChart_Sequence_3_Plus3_TextColor: contrast(@sapChart_Sequence_3_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_3_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_3_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_3_Plus2: lighten(desaturate(@sapChart_Sequence_3, 31), 20);
@sapChart_Sequence_3_Plus2_TextColor: contrast(@sapChart_Sequence_3_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_3_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_3_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_3_Plus1: lighten(desaturate(@sapChart_Sequence_3, 26), 10);
@sapChart_Sequence_3_Plus1_TextColor: contrast(@sapChart_Sequence_3_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_3_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_3_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_3: @sapChart_OrderedColor_3;
@sapChart_Sequence_3_TextColor: contrast(@sapChart_Sequence_3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_3_BorderColor: @sapChart_Sequence_3;
@sapChart_Sequence_3_Minus1: darken(saturate(@sapChart_Sequence_3, 8), 8);
@sapChart_Sequence_3_Minus1_TextColor: contrast(@sapChart_Sequence_3_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_3_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_3_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_3_Minus2: darken(saturate(@sapChart_Sequence_3, 21), 15);
@sapChart_Sequence_3_Minus2_TextColor: contrast(@sapChart_Sequence_3_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_3_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_3_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_3_Minus3: darken(@sapChart_Sequence_3, 20);
@sapChart_Sequence_3_Minus3_TextColor: contrast(@sapChart_Sequence_3_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_3_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_3_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_3_Minus4: darken(@sapChart_Sequence_3, 23);
@sapChart_Sequence_3_Minus4_TextColor: contrast(@sapChart_Sequence_3_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_3_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_3_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_3_Minus5: darken(@sapChart_Sequence_3, 26);
@sapChart_Sequence_3_Minus5_TextColor: contrast(@sapChart_Sequence_3_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_3_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_3_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_4_Plus3: lighten(saturate(@sapChart_Sequence_4, 1), 23);
@sapChart_Sequence_4_Plus3_TextColor: contrast(@sapChart_Sequence_4_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_4_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_4_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_4_Plus2: lighten(@sapChart_Sequence_4, 15);
@sapChart_Sequence_4_Plus2_TextColor: contrast(@sapChart_Sequence_4_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_4_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_4_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_4_Plus1: lighten(@sapChart_Sequence_4, 7);
@sapChart_Sequence_4_Plus1_TextColor: contrast(@sapChart_Sequence_4_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_4_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_4_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_4: @sapChart_OrderedColor_4;
@sapChart_Sequence_4_TextColor: contrast(@sapChart_Sequence_4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_4_BorderColor: @sapChart_Sequence_4;
@sapChart_Sequence_4_Minus1: darken(desaturate(@sapChart_Sequence_4, 5), 5);
@sapChart_Sequence_4_Minus1_TextColor: contrast(@sapChart_Sequence_4_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_4_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_4_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_4_Minus2: darken(saturate(@sapChart_Sequence_4, 10), 17);
@sapChart_Sequence_4_Minus2_TextColor: contrast(@sapChart_Sequence_4_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_4_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_4_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_4_Minus3: darken(@sapChart_Sequence_4, 22);
@sapChart_Sequence_4_Minus3_TextColor: contrast(@sapChart_Sequence_4_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_4_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_4_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_4_Minus4: darken(@sapChart_Sequence_4, 30);
@sapChart_Sequence_4_Minus4_TextColor: contrast(@sapChart_Sequence_4_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_4_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_4_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_4_Minus5: darken(@sapChart_Sequence_4, 35);
@sapChart_Sequence_4_Minus5_TextColor: contrast(@sapChart_Sequence_4_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_4_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_4_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_5_Plus3: lighten(desaturate(@sapChart_Sequence_5, 1), 24);
@sapChart_Sequence_5_Plus3_TextColor: contrast(@sapChart_Sequence_5_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_5_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_5_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_5_Plus2: lighten(@sapChart_Sequence_5, 16);
@sapChart_Sequence_5_Plus2_TextColor: contrast(@sapChart_Sequence_5_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_5_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_5_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_5_Plus1: lighten(@sapChart_Sequence_5, 8);
@sapChart_Sequence_5_Plus1_TextColor: contrast(@sapChart_Sequence_5_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_5_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_5_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_5: @sapChart_OrderedColor_5;
@sapChart_Sequence_5_TextColor: contrast(@sapChart_Sequence_5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_5_BorderColor: @sapChart_Sequence_5_Plus1;
@sapChart_Sequence_5_Minus1: darken(saturate(@sapChart_Sequence_5, 4), 5);
@sapChart_Sequence_5_Minus1_TextColor: contrast(@sapChart_Sequence_5_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_5_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_5_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_5_Minus2: darken(saturate(@sapChart_Sequence_5, 12), 11);
@sapChart_Sequence_5_Minus2_TextColor: contrast(@sapChart_Sequence_5_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_5_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_5_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_5_Minus3: darken(saturate(@sapChart_Sequence_5, 10), 18);
@sapChart_Sequence_5_Minus3_TextColor: contrast(@sapChart_Sequence_5_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_5_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_5_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_5_Minus4: darken(saturate(@sapChart_Sequence_5, 10), 26);
@sapChart_Sequence_5_Minus4_TextColor: contrast(@sapChart_Sequence_5_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_5_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_5_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_5_Minus5: darken(@sapChart_Sequence_5, 35);
@sapChart_Sequence_5_Minus5_TextColor: contrast(@sapChart_Sequence_5_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_5_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_5_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_6_Plus3: lighten(desaturate(@sapChart_Sequence_6, 26), 29);
@sapChart_Sequence_6_Plus3_TextColor: contrast(@sapChart_Sequence_6_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_6_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_6_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_6_Plus2: lighten(desaturate(@sapChart_Sequence_6, 27), 19);
@sapChart_Sequence_6_Plus2_TextColor: contrast(@sapChart_Sequence_6_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_6_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_6_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_6_Plus1: lighten(desaturate(@sapChart_Sequence_6, 26), 10);
@sapChart_Sequence_6_Plus1_TextColor: contrast(@sapChart_Sequence_6_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_6_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_6_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_6: @sapChart_OrderedColor_6;
@sapChart_Sequence_6_TextColor: contrast(@sapChart_Sequence_6, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_6_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_6_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_6_BorderColor: @sapChart_Sequence_6;
@sapChart_Sequence_6_Minus1: darken(saturate(@sapChart_Sequence_6, 4), 6);
@sapChart_Sequence_6_Minus1_TextColor: contrast(@sapChart_Sequence_6_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_6_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_6_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_6_Minus2: darken(saturate(@sapChart_Sequence_6, 8), 12);
@sapChart_Sequence_6_Minus2_TextColor: contrast(@sapChart_Sequence_6_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_6_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_6_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_6_Minus3: darken(saturate(@sapChart_Sequence_6, 5), 16);
@sapChart_Sequence_6_Minus3_TextColor: contrast(@sapChart_Sequence_6_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_6_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_6_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_6_Minus4: darken(saturate(@sapChart_Sequence_6, 5), 20);
@sapChart_Sequence_6_Minus4_TextColor: contrast(@sapChart_Sequence_6_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_6_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_6_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_6_Minus5: darken(saturate(@sapChart_Sequence_6, 5), 25);
@sapChart_Sequence_6_Minus5_TextColor: contrast(@sapChart_Sequence_6_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_6_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_6_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_7_Plus3: lighten(saturate(@sapChart_Sequence_7, 1), 15);
@sapChart_Sequence_7_Plus3_TextColor: contrast(@sapChart_Sequence_7_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_7_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_7_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_7_Plus2: lighten(@sapChart_Sequence_7, 10);
@sapChart_Sequence_7_Plus2_TextColor: contrast(@sapChart_Sequence_7_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_7_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_7_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_7_Plus1: lighten(saturate(@sapChart_Sequence_7, 1), 5);
@sapChart_Sequence_7_Plus1_TextColor: contrast(@sapChart_Sequence_7_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_7_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_7_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_7: @sapChart_OrderedColor_7;
@sapChart_Sequence_7_TextColor: contrast(@sapChart_Sequence_7, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_7_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_7_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_7_BorderColor: @sapChart_Sequence_7_Plus1;
@sapChart_Sequence_7_Minus1: darken(desaturate(@sapChart_Sequence_7, 12), 8);
@sapChart_Sequence_7_Minus1_TextColor: contrast(@sapChart_Sequence_7_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_7_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_7_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_7_Minus2: darken(desaturate(@sapChart_Sequence_7, 18), 15);
@sapChart_Sequence_7_Minus2_TextColor: contrast(@sapChart_Sequence_7_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_7_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_7_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_7_Minus3: darken(desaturate(@sapChart_Sequence_7, 18), 20);
@sapChart_Sequence_7_Minus3_TextColor: contrast(@sapChart_Sequence_7_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_7_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_7_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_7_Minus4: darken(desaturate(@sapChart_Sequence_7, 18), 28);
@sapChart_Sequence_7_Minus4_TextColor: contrast(@sapChart_Sequence_7_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_7_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_7_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_7_Minus5: darken(desaturate(@sapChart_Sequence_7, 18), 36);
@sapChart_Sequence_7_Minus5_TextColor: contrast(@sapChart_Sequence_7_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_7_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_7_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_8_Plus3: lighten(saturate(@sapChart_Sequence_8, 6), 26);
@sapChart_Sequence_8_Plus3_TextColor: contrast(@sapChart_Sequence_8_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_8_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_8_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_8_Plus2: lighten(saturate(@sapChart_Sequence_8, 2), 17);
@sapChart_Sequence_8_Plus2_TextColor: contrast(@sapChart_Sequence_8_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_8_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_8_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_8_Plus1: lighten(@sapChart_Sequence_8, 9);
@sapChart_Sequence_8_Plus1_TextColor: contrast(@sapChart_Sequence_8_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_8_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_8_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_8: @sapChart_OrderedColor_8;
@sapChart_Sequence_8_TextColor: contrast(@sapChart_Sequence_8, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_8_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_8_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_8_BorderColor: @sapChart_Sequence_8_Plus1;
@sapChart_Sequence_8_Minus1: darken(saturate(@sapChart_Sequence_8, 9), 8);
@sapChart_Sequence_8_Minus1_TextColor: contrast(@sapChart_Sequence_8_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_8_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_8_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_8_Minus2: darken(saturate(@sapChart_Sequence_8, 22), 16);
@sapChart_Sequence_8_Minus2_TextColor: contrast(@sapChart_Sequence_8_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_8_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_8_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_8_Minus3: darken(saturate(@sapChart_Sequence_8, 22), 20);
@sapChart_Sequence_8_Minus3_TextColor: contrast(@sapChart_Sequence_8_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_8_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_8_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_8_Minus4: darken(saturate(@sapChart_Sequence_8, 22), 25);
@sapChart_Sequence_8_Minus4_TextColor: contrast(@sapChart_Sequence_8_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_8_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_8_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_8_Minus5: darken(saturate(@sapChart_Sequence_8, 22), 32);
@sapChart_Sequence_8_Minus5_TextColor: contrast(@sapChart_Sequence_8_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .3);
@sapChart_Sequence_8_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_8_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_9_Plus3: lighten(desaturate(@sapChart_Sequence_9, 2), 34);
@sapChart_Sequence_9_Plus3_TextColor: contrast(@sapChart_Sequence_9_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_9_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_9_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_9_Plus2: lighten(@sapChart_Sequence_9, 22);
@sapChart_Sequence_9_Plus2_TextColor: contrast(@sapChart_Sequence_9_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_9_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_9_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_9_Plus1: lighten(@sapChart_Sequence_9, 11);
@sapChart_Sequence_9_Plus1_TextColor: contrast(@sapChart_Sequence_9_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_9_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_9_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_9: @sapChart_OrderedColor_9;
@sapChart_Sequence_9_TextColor: contrast(@sapChart_Sequence_9, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_9_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_9_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_9_BorderColor: @sapChart_Sequence_9;
@sapChart_Sequence_9_Minus1: darken(saturate(@sapChart_Sequence_9, 6), 8);
@sapChart_Sequence_9_Minus1_TextColor: contrast(@sapChart_Sequence_9_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_9_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_9_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_9_Minus2: darken(saturate(@sapChart_Sequence_9, 16), 16);
@sapChart_Sequence_9_Minus2_TextColor: contrast(@sapChart_Sequence_9_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_9_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_9_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_9_Minus3: darken(saturate(@sapChart_Sequence_9, 16), 24);
@sapChart_Sequence_9_Minus3_TextColor: contrast(@sapChart_Sequence_9_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_9_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_9_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_9_Minus4: darken(saturate(@sapChart_Sequence_9, 16), 32);
@sapChart_Sequence_9_Minus4_TextColor: contrast(@sapChart_Sequence_9_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_9_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_9_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_9_Minus5: darken(saturate(@sapChart_Sequence_9, 16), 38);
@sapChart_Sequence_9_Minus5_TextColor: contrast(@sapChart_Sequence_9_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_9_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_9_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_10_Plus3: lighten(saturate(@sapChart_Sequence_10, 9), 22);
@sapChart_Sequence_10_Plus3_TextColor: contrast(@sapChart_Sequence_10_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_10_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_10_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_10_Plus2: lighten(saturate(@sapChart_Sequence_10, 5), 14);
@sapChart_Sequence_10_Plus2_TextColor: contrast(@sapChart_Sequence_10_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_10_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_10_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_10_Plus1: lighten(saturate(@sapChart_Sequence_10, 2), 7);
@sapChart_Sequence_10_Plus1_TextColor: contrast(@sapChart_Sequence_10_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_10_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_10_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_10: @sapChart_OrderedColor_10;
@sapChart_Sequence_10_TextColor: contrast(@sapChart_Sequence_10, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_10_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_10_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_10_BorderColor: @sapChart_Sequence_10_Minus1;
@sapChart_Sequence_10_Minus1: darken(desaturate(@sapChart_Sequence_10, 8), 8);
@sapChart_Sequence_10_Minus1_TextColor: contrast(@sapChart_Sequence_10_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_10_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_10_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_10_Minus2: darken(desaturate(@sapChart_Sequence_10, 13), 16);
@sapChart_Sequence_10_Minus2_TextColor: contrast(@sapChart_Sequence_10_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_10_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_10_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_10_Minus3: darken(desaturate(@sapChart_Sequence_10, 13), 22);
@sapChart_Sequence_10_Minus3_TextColor: contrast(@sapChart_Sequence_10_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_10_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_10_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_10_Minus4: darken(desaturate(@sapChart_Sequence_10, 13), 28);
@sapChart_Sequence_10_Minus4_TextColor: contrast(@sapChart_Sequence_10_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_10_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_10_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_10_Minus5: darken(desaturate(@sapChart_Sequence_10, 13), 34);
@sapChart_Sequence_10_Minus5_TextColor: contrast(@sapChart_Sequence_10_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_10_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_10_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_11_Plus3: lighten(desaturate(@sapChart_Sequence_11, 8), 24);
@sapChart_Sequence_11_Plus3_TextColor: contrast(@sapChart_Sequence_11_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_11_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_11_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_11_Plus2: lighten(desaturate(@sapChart_Sequence_11, 8), 16);
@sapChart_Sequence_11_Plus2_TextColor: contrast(@sapChart_Sequence_11_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_11_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_11_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_11_Plus1: lighten(desaturate(@sapChart_Sequence_11, 6), 8);
@sapChart_Sequence_11_Plus1_TextColor: contrast(@sapChart_Sequence_11_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_11_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_11_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_11: @sapChart_OrderedColor_11;
@sapChart_Sequence_11_TextColor: contrast(@sapChart_Sequence_11, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_11_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_11_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_11_BorderColor: @sapChart_Sequence_11;
@sapChart_Sequence_11_Minus1: darken(saturate(@sapChart_Sequence_11, 17), 8);
@sapChart_Sequence_11_Minus1_TextColor: contrast(@sapChart_Sequence_11_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_11_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_11_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_11_Minus2: darken(saturate(@sapChart_Sequence_11, 24), 12);
@sapChart_Sequence_11_Minus2_TextColor: contrast(@sapChart_Sequence_11_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_11_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_11_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_11_Minus3: darken(saturate(@sapChart_Sequence_11, 37), 18);
@sapChart_Sequence_11_Minus3_TextColor: contrast(@sapChart_Sequence_11_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_11_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_11_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_11_Minus4: darken(saturate(@sapChart_Sequence_11, 36), 24);
@sapChart_Sequence_11_Minus4_TextColor: contrast(@sapChart_Sequence_11_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_11_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_11_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_11_Minus5: darken(saturate(@sapChart_Sequence_11, 36), 30);
@sapChart_Sequence_11_Minus5_TextColor: contrast(@sapChart_Sequence_11_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_11_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_11_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_12_Plus3: lighten(desaturate(@sapChart_Sequence_12, 34), 31.2);
@sapChart_Sequence_12_Plus3_TextColor: contrast(@sapChart_Sequence_12_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_12_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_12_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_12_Plus2: lighten(saturate(@sapChart_Sequence_12, 16), 23.8);
@sapChart_Sequence_12_Plus2_TextColor: contrast(@sapChart_Sequence_12_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_12_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_12_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_12_Plus1: lighten(saturate(@sapChart_Sequence_12, 5), 11.2);
@sapChart_Sequence_12_Plus1_TextColor: contrast(@sapChart_Sequence_12_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_12_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_12_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_12: @sapChart_OrderedColor_12;
@sapChart_Sequence_12_TextColor: contrast(@sapChart_Sequence_12, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_12_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_12_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_12_BorderColor: @sapChart_Sequence_12;
@sapChart_Sequence_12_Minus1: darken(saturate(@sapChart_Sequence_12, 1), 13.2);
@sapChart_Sequence_12_Minus1_TextColor: contrast(@sapChart_Sequence_12_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_12_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_12_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_12_Minus2: darken(saturate(@sapChart_Sequence_12, 17), 24.6);
@sapChart_Sequence_12_Minus2_TextColor: contrast(@sapChart_Sequence_12_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_12_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_12_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_12_Minus3: darken(saturate(@sapChart_Sequence_12, 17), 28);
@sapChart_Sequence_12_Minus3_TextColor: contrast(@sapChart_Sequence_12_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_12_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_12_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_12_Minus4: darken(saturate(@sapChart_Sequence_12, 17), 32);
@sapChart_Sequence_12_Minus4_TextColor: contrast(@sapChart_Sequence_12_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_12_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_12_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_12_Minus5: darken(saturate(@sapChart_Sequence_12, 17), 38);
@sapChart_Sequence_12_Minus5_TextColor: contrast(@sapChart_Sequence_12_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .5);
@sapChart_Sequence_12_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_12_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Bad_Plus3: lighten(@sapChart_Sequence_Bad, 32);
@sapChart_Sequence_Bad_Plus3_TextColor: contrast(@sapChart_Sequence_Bad_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .35);
@sapChart_Sequence_Bad_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Bad_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Bad_Plus2: lighten(@sapChart_Sequence_Bad, 22);
@sapChart_Sequence_Bad_Plus2_TextColor: contrast(@sapChart_Sequence_Bad_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .35);
@sapChart_Sequence_Bad_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Bad_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Bad_Plus1: lighten(@sapChart_Sequence_Bad, 12);
@sapChart_Sequence_Bad_Plus1_TextColor: contrast(@sapChart_Sequence_Bad_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .35);
@sapChart_Sequence_Bad_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Bad_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_Bad: @sapChart_Bad;
@sapChart_Sequence_Bad_TextColor: contrast(@sapChart_Sequence_Bad, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .35);
@sapChart_Sequence_Bad_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Bad_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Bad_BorderColor: @sapChart_Sequence_Bad_Plus1;
@sapChart_Sequence_Bad_Minus1: darken(desaturate(@sapChart_Sequence_Bad, 1), 7);
@sapChart_Sequence_Bad_Minus1_TextColor: contrast(@sapChart_Sequence_Bad_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .35);
@sapChart_Sequence_Bad_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Bad_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Bad_Minus2: darken(desaturate(@sapChart_Sequence_Bad, 1), 7);
@sapChart_Sequence_Bad_Minus2_TextColor: contrast(@sapChart_Sequence_Bad_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .35);
@sapChart_Sequence_Bad_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Bad_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Bad_Minus3: darken(@sapChart_Sequence_Bad, 20);
@sapChart_Sequence_Bad_Minus3_TextColor: contrast(@sapChart_Sequence_Bad_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .35);
@sapChart_Sequence_Bad_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Bad_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Bad_Minus4: darken(@sapChart_Sequence_Bad, 28);
@sapChart_Sequence_Bad_Minus4_TextColor: contrast(@sapChart_Sequence_Bad_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .35);
@sapChart_Sequence_Bad_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Bad_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Bad_Minus5: darken(@sapChart_Sequence_Bad, 34);
@sapChart_Sequence_Bad_Minus5_TextColor: contrast(@sapChart_Sequence_Bad_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .35);
@sapChart_Sequence_Bad_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Bad_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Critical_Plus3: lighten(@sapChart_Sequence_Critical, 30);
@sapChart_Sequence_Critical_Plus3_TextColor: contrast(@sapChart_Sequence_Critical_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Critical_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Critical_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Critical_Plus2: lighten(@sapChart_Sequence_Critical, 17);
@sapChart_Sequence_Critical_Plus2_TextColor: contrast(@sapChart_Sequence_Critical_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Critical_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Critical_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Critical_Plus1: lighten(@sapChart_Sequence_Critical, 7);
@sapChart_Sequence_Critical_Plus1_TextColor: contrast(@sapChart_Sequence_Critical_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Critical_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Critical_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_Critical: @sapChart_Critical;
@sapChart_Sequence_Critical_TextColor: contrast(@sapChart_Sequence_Critical, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Critical_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Critical_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Critical_BorderColor: @sapChart_Sequence_Critical;
@sapChart_Sequence_Critical_Minus1: darken(@sapChart_Sequence_Critical, 5);
@sapChart_Sequence_Critical_Minus1_TextColor: contrast(@sapChart_Sequence_Critical_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Critical_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Critical_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Critical_Minus2: darken(@sapChart_Sequence_Critical, 12);
@sapChart_Sequence_Critical_Minus2_TextColor: contrast(@sapChart_Sequence_Critical_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Critical_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Critical_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Critical_Minus3: darken(@sapChart_Sequence_Critical, 18);
@sapChart_Sequence_Critical_Minus3_TextColor: contrast(@sapChart_Sequence_Critical_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Critical_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Critical_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Critical_Minus4: darken(@sapChart_Sequence_Critical, 24);
@sapChart_Sequence_Critical_Minus4_TextColor: contrast(@sapChart_Sequence_Critical_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Critical_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Critical_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Critical_Minus5: darken(@sapChart_Sequence_Critical, 30);
@sapChart_Sequence_Critical_Minus5_TextColor: contrast(@sapChart_Sequence_Critical_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Critical_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Critical_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Good_Plus3: lighten(@sapChart_Sequence_Good, 30);
@sapChart_Sequence_Good_Plus3_TextColor: contrast(@sapChart_Sequence_Good_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Good_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Good_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Good_Plus2: lighten(@sapChart_Sequence_Good, 17);
@sapChart_Sequence_Good_Plus2_TextColor: contrast(@sapChart_Sequence_Good_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Good_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Good_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Good_Plus1: lighten(@sapChart_Sequence_Good, 7);
@sapChart_Sequence_Good_Plus1_TextColor: contrast(@sapChart_Sequence_Good_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Good_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Good_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_Good: @sapChart_Good;
@sapChart_Sequence_Good_TextColor: contrast(@sapChart_Sequence_Good, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Good_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Good_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Good_BorderColor: @sapChart_Sequence_Good;
@sapChart_Sequence_Good_Minus1: darken(@sapChart_Sequence_Good, 7);
@sapChart_Sequence_Good_Minus1_TextColor: contrast(@sapChart_Sequence_Good_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Good_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Good_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Good_Minus2: darken(@sapChart_Sequence_Good, 15);
@sapChart_Sequence_Good_Minus2_TextColor: contrast(@sapChart_Sequence_Good_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Good_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Good_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Good_Minus3: darken(@sapChart_Sequence_Good, 20);
@sapChart_Sequence_Good_Minus3_TextColor: contrast(@sapChart_Sequence_Good_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Good_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Good_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Good_Minus4: darken(@sapChart_Sequence_Good, 24);
@sapChart_Sequence_Good_Minus4_TextColor: contrast(@sapChart_Sequence_Good_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Good_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Good_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Good_Minus5: darken(@sapChart_Sequence_Good, 28);
@sapChart_Sequence_Good_Minus5_TextColor: contrast(@sapChart_Sequence_Good_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Good_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Good_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Neutral_Plus3: lighten(saturate(@sapChart_Sequence_Neutral, 1), 30);
@sapChart_Sequence_Neutral_Plus3_TextColor: contrast(@sapChart_Sequence_Neutral_Plus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Neutral_Plus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Neutral_Plus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Neutral_Plus2: lighten(saturate(@sapChart_Sequence_Neutral, 1), 20);
@sapChart_Sequence_Neutral_Plus2_TextColor: contrast(@sapChart_Sequence_Neutral_Plus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Neutral_Plus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Neutral_Plus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Neutral_Plus1: lighten(saturate(@sapChart_Sequence_Neutral, 1), 10);
@sapChart_Sequence_Neutral_Plus1_TextColor: contrast(@sapChart_Sequence_Neutral_Plus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Neutral_Plus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Neutral_Plus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);

// [Tags "!Protected"]
// [Protected "!true"]
@sapChart_Sequence_Neutral: @sapChart_Neutral;
@sapChart_Sequence_Neutral_TextColor: contrast(@sapChart_Sequence_Neutral, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Neutral_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Neutral_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Neutral_BorderColor: @sapChart_Sequence_Neutral;
@sapChart_Sequence_Neutral_Minus1: darken(saturate(@sapChart_Sequence_Neutral, 1), 10);
@sapChart_Sequence_Neutral_Minus1_TextColor: contrast(@sapChart_Sequence_Neutral_Minus1, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Neutral_Minus1_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Neutral_Minus1_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Neutral_Minus2: darken(saturate(@sapChart_Sequence_Neutral, 1), 17);
@sapChart_Sequence_Neutral_Minus2_TextColor: contrast(@sapChart_Sequence_Neutral_Minus2, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Neutral_Minus2_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Neutral_Minus2_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Neutral_Minus3: darken(@sapChart_Sequence_Neutral, 26);
@sapChart_Sequence_Neutral_Minus3_TextColor: contrast(@sapChart_Sequence_Neutral_Minus3, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Neutral_Minus3_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Neutral_Minus3_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Neutral_Minus4: darken(@sapChart_Sequence_Neutral, 34);
@sapChart_Sequence_Neutral_Minus4_TextColor: contrast(@sapChart_Sequence_Neutral_Minus4, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Neutral_Minus4_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Neutral_Minus4_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapChart_Sequence_Neutral_Minus5: darken(@sapChart_Sequence_Neutral, 40);
@sapChart_Sequence_Neutral_Minus5_TextColor: contrast(@sapChart_Sequence_Neutral_Minus5, @sapChart_Data_TextColor, @sapChart_Data_ContrastTextColor, .45);
@sapChart_Sequence_Neutral_Minus5_TextShadow: 0 0 .125rem contrast(@sapChart_Sequence_Neutral_Minus5_TextColor, @sapContent_ShadowColor, @sapChart_ContrastShadowColor, @sapContent_ContrastTextThreshold);
@sapFontUrl_SAP-icons_ttf: url(./../baseTheme/fonts/SAP-icons.ttf);
@sapFontUrl_SAP-icons_woff: url(./../baseTheme/fonts/SAP-icons.woff);
@sapFontUrl_SAP-icons_woff2: url(./../baseTheme/fonts/SAP-icons.woff2);
@sapFontUrl_SAP-icons-TNT_ttf: url(./../baseTheme/fonts/SAP-icons-TNT.ttf);
@sapFontUrl_SAP-icons-TNT_woff: url(./../baseTheme/fonts/SAP-icons-TNT.woff);
@sapFontUrl_SAP-icons-TNT_woff2: url(./../baseTheme/fonts/SAP-icons-TNT.woff2);
@sapFontUrl_SAP-icons-Business-Suite_ttf: url(./../baseTheme/fonts/BusinessSuiteInAppSymbols.ttf);
@sapFontUrl_SAP-icons-Business-Suite_woff: url(./../baseTheme/fonts/BusinessSuiteInAppSymbols.woff);
@sapFontUrl_SAP-icons-Business-Suite_woff2: url(./../baseTheme/fonts/BusinessSuiteInAppSymbols.woff2);
@sapFontUrl_72_Regular_woff2: url(./../baseTheme/fonts/72-Regular.woff2);
@sapFontUrl_72_Regular_woff: url(./../baseTheme/fonts/72-Regular.woff);
@sapFontUrl_72_Regular_full_woff2: url(./../baseTheme/fonts/72-Regular-full.woff2);
@sapFontUrl_72_Regular_full_woff: url(./../baseTheme/fonts/72-Regular-full.woff);
@sapFontUrl_72_Bold_woff2: url(./../baseTheme/fonts/72-Bold.woff2);
@sapFontUrl_72_Bold_woff: url(./../baseTheme/fonts/72-Bold.woff);
@sapFontUrl_72_Bold_full_woff2: url(./../baseTheme/fonts/72-Bold-full.woff2);
@sapFontUrl_72_Bold_full_woff: url(./../baseTheme/fonts/72-Bold-full.woff);
@sapFontUrl_72_Semibold_woff2: url(./../baseTheme/fonts/72-Semibold.woff2);
@sapFontUrl_72_Semibold_woff: url(./../baseTheme/fonts/72-Semibold.woff);
@sapFontUrl_72_Semibold_full_woff2: url(./../baseTheme/fonts/72-Semibold-full.woff2);
@sapFontUrl_72_Semibold_full_woff: url(./../baseTheme/fonts/72-Semibold-full.woff);
@sapFontUrl_72_SemiboldDuplex_woff2: url(./../baseTheme/fonts/72-SemiboldDuplex.woff2);
@sapFontUrl_72_SemiboldDuplex_woff: url(./../baseTheme/fonts/72-SemiboldDuplex.woff);
@sapFontUrl_72_SemiboldDuplex_full_woff2: url(./../baseTheme/fonts/72-SemiboldDuplex-full.woff2);
@sapFontUrl_72_SemiboldDuplex_full_woff: url(./../baseTheme/fonts/72-SemiboldDuplex-full.woff);
@sapFontUrl_72_Light_woff2: url(./../baseTheme/fonts/72-Light.woff2);
@sapFontUrl_72_Light_woff: url(./../baseTheme/fonts/72-Light.woff);
@sapFontUrl_72_Light_full_woff2: url(./../baseTheme/fonts/72-Light-full.woff2);
@sapFontUrl_72_Light_full_woff: url(./../baseTheme/fonts/72-Light-full.woff);
@sapFontUrl_72_Black_woff2: url(./../baseTheme/fonts/72-Black.woff2);
@sapFontUrl_72_Black_woff: url(./../baseTheme/fonts/72-Black.woff);
@sapFontUrl_72_Black_full_woff2: url(./../baseTheme/fonts/72-Black-full.woff2);
@sapFontUrl_72_Black_full_woff: url(./../baseTheme/fonts/72-Black-full.woff);
@sapFontUrl_72_BoldItalic_woff2: url(./../baseTheme/fonts/72-BoldItalic.woff2);
@sapFontUrl_72_BoldItalic_woff: url(./../baseTheme/fonts/72-BoldItalic.woff);
@sapFontUrl_72_BoldItalic_full_woff2: url(./../baseTheme/fonts/72-BoldItalic-full.woff2);
@sapFontUrl_72_BoldItalic_full_woff: url(./../baseTheme/fonts/72-BoldItalic-full.woff);
@sapFontUrl_72_Condensed_woff2: url(./../baseTheme/fonts/72-Condensed.woff2);
@sapFontUrl_72_Condensed_woff: url(./../baseTheme/fonts/72-Condensed.woff);
@sapFontUrl_72_Condensed_full_woff2: url(./../baseTheme/fonts/72-Condensed-full.woff2);
@sapFontUrl_72_Condensed_full_woff: url(./../baseTheme/fonts/72-Condensed-full.woff);
@sapFontUrl_72_CondensedBold_woff2: url(./../baseTheme/fonts/72-CondensedBold.woff2);
@sapFontUrl_72_CondensedBold_woff: url(./../baseTheme/fonts/72-CondensedBold.woff);
@sapFontUrl_72_CondensedBold_full_woff2: url(./../baseTheme/fonts/72-CondensedBold-full.woff2);
@sapFontUrl_72_CondensedBold_full_woff: url(./../baseTheme/fonts/72-CondensedBold-full.woff);
@sapFontUrl_72_Italic_woff2: url(./../baseTheme/fonts/72-Italic.woff2);
@sapFontUrl_72_Italic_woff: url(./../baseTheme/fonts/72-Italic.woff);
@sapFontUrl_72_Italic_full_woff2: url(./../baseTheme/fonts/72-Italic-full.woff2);
@sapFontUrl_72_Italic_full_woff: url(./../baseTheme/fonts/72-Italic-full.woff);
@sapFontUrl_72Mono_Regular_woff2: url(./../baseTheme/fonts/72Mono-Regular.woff2);
@sapFontUrl_72Mono_Regular_woff: url(./../baseTheme/fonts/72Mono-Regular.woff);
@sapFontUrl_72Mono_Regular_full_woff2: url(./../baseTheme/fonts/72Mono-Regular-full.woff2);
@sapFontUrl_72Mono_Regular_full_woff: url(./../baseTheme/fonts/72Mono-Regular-full.woff);
@sapFontUrl_72Mono_Bold_woff2: url(./../baseTheme/fonts/72Mono-Bold.woff2);
@sapFontUrl_72Mono_Bold_woff: url(./../baseTheme/fonts/72Mono-Bold.woff);
@sapFontUrl_72Mono_Bold_full_woff2: url(./../baseTheme/fonts/72Mono-Bold-full.woff2);
@sapFontUrl_72Mono_Bold_full_woff: url(./../baseTheme/fonts/72Mono-Bold-full.woff);
@sapSvgLib_SAP-icons: none;
@sapSvgLib_SAPGUI-icons: url(./../sap_fiori_3/svg/libs/SAPGUI-icons.svg);
@sapSvgLib_SAPWeb-icons: url(./../sap_fiori_3/svg/libs/SAPWeb-icons.svg);
@sapSapThemeId: sap_fiori_3_dark;
@sapBackgroundColorDefault: darken(@sapPrimary3, 6);
@sapList_HighlightColor: @sapHighlightColor;
@sapShell_BackgroundGradient: linear-gradient(to bottom, darken(@sapShell_Background, 5), lighten(@sapShell_Background, 2));
@sapBreakpoint_S_Min: 0;
@sapBreakpoint_M_Min: 600px;
@sapBreakpoint_L_Min: 1024px;
@sapBreakpoint_XL_Min: 1440px;
